[Catalyst-commits] r7734 - / Catalyst-Devel/1.10/trunk Catalyst-Devel/1.10/trunk/lib/Catalyst

zarquon at dev.catalyst.perl.org zarquon at dev.catalyst.perl.org
Sun May 11 04:06:57 BST 2008


Author: zarquon
Date: 2008-05-11 04:06:57 +0100 (Sun, 11 May 2008)
New Revision: 7734

Modified:
   /
   Catalyst-Devel/1.10/trunk/Changes
   Catalyst-Devel/1.10/trunk/Makefile.PL
   Catalyst-Devel/1.10/trunk/lib/Catalyst/Helper.pm
Log:
 r13101 at zaphod:  kd | 2008-05-11 13:01:45 +1000
 moved from yaml to config::general as default format



Property changes on: 
___________________________________________________________________
Name: svk:merge
   - 1b129c88-ebf4-0310-add9-f09427935aba:/local/catalyst:4278
1c72fc7c-9ce4-42af-bf25-3bfe470ff1e8:/local/Catalyst:13030
3b9770f9-e80c-0410-a7de-cd203d167417:/local/catalyst:3514
dd8ad9ea-0304-0410-a433-df5f223e7bc0:/local/Catalyst:6909
   + 1b129c88-ebf4-0310-add9-f09427935aba:/local/catalyst:4278
1c72fc7c-9ce4-42af-bf25-3bfe470ff1e8:/local/Catalyst:13101
3b9770f9-e80c-0410-a7de-cd203d167417:/local/catalyst:3514
dd8ad9ea-0304-0410-a433-df5f223e7bc0:/local/Catalyst:6909

Modified: Catalyst-Devel/1.10/trunk/Changes
===================================================================
--- Catalyst-Devel/1.10/trunk/Changes	2008-05-10 02:27:05 UTC (rev 7733)
+++ Catalyst-Devel/1.10/trunk/Changes	2008-05-11 03:06:57 UTC (rev 7734)
@@ -1,5 +1,7 @@
 This file documents the revision history for Perl extension Catalyst-Devel.
 
+1.10    2008-05-11
+        - Moved Helper.pm to generate .conf rather than YAML
 1.04	2007-XX-XX
         - Patch Helper.pm so Module::Pluggable::Object ignores emacs temp
           files appropriately for restarting server

Modified: Catalyst-Devel/1.10/trunk/Makefile.PL
===================================================================
--- Catalyst-Devel/1.10/trunk/Makefile.PL	2008-05-10 02:27:05 UTC (rev 7733)
+++ Catalyst-Devel/1.10/trunk/Makefile.PL	2008-05-11 03:06:57 UTC (rev 7734)
@@ -14,7 +14,7 @@
 requires 'Catalyst::Action::RenderView' => '0.04';
 requires 'Catalyst::Plugin::Static::Simple' => '0.16';
 requires 'Catalyst::Plugin::ConfigLoader';
-requires 'YAML'        => '0.55';
+requires 'Config::General';
 requires 'Module::Install' => '0.64';
 requires 'File::Copy::Recursive';
 

Modified: Catalyst-Devel/1.10/trunk/lib/Catalyst/Helper.pm
===================================================================
--- Catalyst-Devel/1.10/trunk/lib/Catalyst/Helper.pm	2008-05-10 02:27:05 UTC (rev 7733)
+++ Catalyst-Devel/1.10/trunk/lib/Catalyst/Helper.pm	2008-05-11 03:06:57 UTC (rev 7734)
@@ -376,7 +376,7 @@
     my $dir       = $self->{dir};
     my $appprefix = $self->{appprefix};
     $self->render_file( 'config',
-        File::Spec->catfile( $dir, "$appprefix.yml" ) );
+        File::Spec->catfile( $dir, "$appprefix.conf" ) );
 }
 
 sub _mk_readme {
@@ -564,7 +564,7 @@
 
 # Configure the application. 
 #
 # Note that settings in [% appprefix %].yml (or other external
 # configuration file that you set up manually) take precedence
 # over this when using ConfigLoader. Thus configuration
 # details given here can function as a default configuration,
@@ -671,7 +671,7 @@
 requires 'Catalyst::Plugin::ConfigLoader';
 requires 'Catalyst::Plugin::Static::Simple';
 requires 'Catalyst::Action::RenderView';
-requires 'YAML'; # This should reflect the config file format you've chosen
+requires 'Config::General'; # This should reflect the config file format you've chosen
                  # See Catalyst::Plugin::ConfigLoader for supported formats
 catalyst;
 
@@ -680,7 +680,9 @@
 WriteAll;
 __config__
 ---
-name: [% name %]
+# rename this file to [% name %].yml and put a : in front of "name" if
+# you want to use yaml like in old versions of Catalyst
+name [% name %]
 __readme__
 Run script/[% appprefix %]_server.pl to test the application.
 __changes__
@@ -859,7 +861,7 @@
 my $keepalive         = 0;
 my $restart           = $ENV{[% appenv %]_RELOAD} || $ENV{CATALYST_RELOAD} || 0;
 my $restart_delay     = 1;
-my $restart_regex     = '(?:/|^)(?!\.#).+(?:\.yml$|\.yaml$|\.pm)$';
+my $restart_regex     = '(?:/|^)(?!\.#).+(?:\.yml$|\.yaml$||\.conf|\.pm)$';
 my $restart_directory = undef;
 my $follow_symlinks   = 0;
 
@@ -926,7 +928,7 @@
    -rd -restartdelay  delay between file checks
    -rr -restartregex  regex match files that trigger
                       a restart when modified
-                      (defaults to '\.yml$|\.yaml$|\.pm$')
+                      (defaults to '\.yml$|\.yaml$|\.conf|\.pm$')
    -restartdirectory  the directory to search for
                       modified files, can be set mulitple times
                       (defaults to '[SCRIPT_DIR]/..')
@@ -564,7 +564,7 @@
 # Configure the application. 
 #
-# Note that settings in [% appprefix %].yml (or other external
+# Note that settings in [% appprefix %].conf (or other external
 # configuration file that you set up manually) take precedence
 # over this when using ConfigLoader. Thus configuration




More information about the Catalyst-commits mailing list